@@ -22,13 +22,14 @@ def load_resources(refresh: bool = False):
     else:
         logger.info("Loading resources in memory...")
 
-    from robotoff import logos, taxonomy
+    from robotoff import brands, logos, taxonomy
     from robotoff.prediction.category import matcher
     from robotoff.prediction.object_detection import ObjectDetectionModelRegistry
 
     matcher.load_resources()
     taxonomy.load_resources()
     logos.load_resources()
+    brands.load_resources()
 
     if not refresh:
         logger.info("Loading object detection model labels...")
